package hello.jsp;

import javax.servlet.*; 
import javax.servlet.http.*;
import java.io.*;
import org.apache.struts.action.*;

/**
 * Extends ActionServlet to provide initialization of additional parameters.
 * We would not have to extend ActionServlet if we did not require those
 * parameters. Another approach would be to have an additional servlet
 * just for that purpose.
 * $Revision: 1.3 $ $Date: 2002/10/06 22:46:47 $ (helder@acm.org).
 */
public class MessageActionServlet extends ActionServlet {

    /**
     * The data access object which provedes the persistence mechanism for this application.
     */
    private MessageBeanDAO dao;
    
    /**
     * Loads servlet's initial parameters.
     */
    public void init(ServletConfig config) throws ServletException {
        // Persistence mechanism and location
        String messageDir = config.getInitParameter("message-dir");
        String dsn = config.getInitParameter("data-source-name");
        if (dsn == null && messageDir != null) { // using XML persistence
            dao = new XMLMessageBeanDAO(messageDir);
        } else if (messageDir == null && dsn != null) { // using datasource persistence
            //dao = new JDOMessageBeanDAO(dsn);
            throw new UnavailableException("JDO persistence not yet implemented! Use XML binding!");
        } else {
            throw new UnavailableException("Either message-dir or data-source-name must be present in deployment descriptor");
        }
        super.init(config);
    }
    
    /**
     * Saves param in request.
     */
    public void service (HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        request.setAttribute("dao", dao);
        super.service(request, response);
    }

}
