package hello.jsp;

import javax.servlet.*; 
import javax.servlet.http.*;
import java.io.*;

import org.apache.cactus.*;
import junit.framework.*;
import org.apache.struts.action.*;
import org.apache.struts.config.ForwardConfig;

/**
 * Tests the results of NewMessageCommand.
 * $Revision: 1.2 $ $Date: 2002/10/06 22:46:48 $ (helder@acm.org).
 */
public class NewMessageActionTest extends ServletTestCase {
    
    public NewMessageActionTest(String name) {
        super(name);
    }
    public static Test suite() {
        return new TestSuite(NewMessageActionTest.class);
    }

    private NewMessageAction command;
    private String testMessage = "This is a test message";
    private ActionMapping mapping;
    private NewMessageForm form; 
    private MessageBeanDAO testDAO; 
    
    public void beginExecute(WebRequest clientRequest) {
        clientRequest.addParameter("message", testMessage);
    }
    
    public void setUp() throws IOException {
        File testDir = new File("/tmp/test");
        testDir.mkdir();
        testDAO = new XMLMessageBeanDAO("/tmp/test");
        request.setAttribute("dao", testDAO);
        mapping = new ActionMapping();
        mapping.addForwardConfig(new ActionForward("failure", "/index.jsp", false)); // global definition
        mapping.addForwardConfig(new ActionForward("success", "/lastMessage.jsp", false));
        form = new NewMessageForm();
    }
    
    public void testExecute() throws ServletException, IOException {
        
        String message = request.getParameter("message");
        assertEquals("Wrong message!", testMessage, message);
        form.setMessage(message);
        
        command = new NewMessageAction();
        ActionForward fwdObj = command.execute(mapping, form, request, response);
        
        // dao attribute should exist
        MessageBeanDAO dao = (MessageBeanDAO)request.getAttribute("dao");
        assertNotNull("Attribute not set.", dao);
        assertEquals("Wrong data locator", "/tmp/test", dao.getLocator());
        
        // message.count should exist
        File countFile = new File("/tmp/test/message.count");
        assertTrue("Count file does not exist!", countFile.exists());
        
        // lastMessage attribute in request should exist with messageBean which contains message
        Object attribute = request.getAttribute("messageBean");
        assertNotNull("No attribute messageBean exists in Session.", attribute);
        MessageBean bean = (MessageBean)attribute;
        String result = bean.getMessage();
        assertEquals("Message received does not match message sent.", testMessage, result);
        
        // This asserts that the forward name is what we expect - runtime value
        String target = fwdObj.getName();
        assertEquals("Unexpected returned target.", "success", target);
        
        // the value defined in struts-config.xml - configuration value
        String path = fwdObj.getPath();
        assertEquals("Unexpected returned path.", "/lastMessage.jsp", path);
        
    }
    
}
