package hello.jsp; 

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

import org.apache.cactus.*;
import junit.framework.*;
import org.apache.struts.action.*;
import org.apache.struts.config.ForwardConfig;

/**
 * $Revision: 1.2 $ $Date: 2002/10/06 22:46:48 $ (helder@acm.org).
 */
public class ShowLastMessageActionTest extends ServletTestCase {
    
    public ShowLastMessageActionTest(String name) {
        super(name);
    }
    public static Test suite() {
        return new TestSuite(ShowLastMessageActionTest.class);
    }

    private ShowLastMessageAction command;
    private String testMessage = "This is a test message"; // this is the text for all messages
    private ActionMapping mapping;
    private NewMessageForm form; 
    private MessageBeanDAO testDAO; 
    
    public void beginExecute(WebRequest clientRequest) {
        // no parameters to set
    }
    
    public void setUp() throws IOException {
        testDAO = new XMLMessageBeanDAO("/tmp/test");
        request.setAttribute("dao", testDAO);
        mapping = new ActionMapping();
        mapping.addForwardConfig(new ActionForward("failure", "/index.jsp", false)); // global definition
        mapping.addForwardConfig(new ActionForward("success", "/lastMessage.jsp", false));
        form = new NewMessageForm();
        command = new ShowLastMessageAction();
    }
    
    /**
     * This test is practically the same as the test for NewMessageCommand. The difference is
     * that the message received was unmarshaled from the XML file. Additionally, this test
     * will only run if the files exist (ex: the other test must run before this one.)
     * We do not test to see the contents of this message since this test has no control over that.
     */
    public void testExecute() throws ServletException, IOException {
        ActionForward fwdObj = command.execute(mapping, form, request, response);
        
        // dao attribute should exist
        MessageBeanDAO dao = (MessageBeanDAO)request.getAttribute("dao");
        assertNotNull("Attribute not set.", dao);
        assertEquals("Wrong data locator", "/tmp/test", dao.getLocator());
        
        // message.count should exist
        File countFile = new File("/tmp/test/message.count");
        assertTrue("Count file does not exist!", countFile.exists());
        
        // lastMessage attribute in request should exist with messageBean
        // This is an unmarshaled version
        Object attribute = request.getAttribute("messageBean");
        assertNotNull("No attribute messageBean exists in Session.", attribute);
        MessageBean bean = (MessageBean)attribute;
        String result = bean.getMessage();
        assertNotNull("Message is null.", result); // we just check that there is a message
        System.out.println("Last message found: " + result);
        
        // This asserts that the forward name is what we expect - runtime value
        String target = fwdObj.getName();
        assertEquals("Unexpected returned target.", "success", target);
        
        // the value defined in struts-config.xml - configuration value
        String path = fwdObj.getPath();
        assertEquals("Unexpected returned path.", "/lastMessage.jsp", path);
    }
    
}
